@@ -13,14 +13,14 @@ declare
     data jsonb;
 begin
     -- Create a temp table to hold the JSON data
-    create temp table temp_pgbackrest_data (data jsonb);
+    create temp table temp_pgbackrest_data (data text);
 
     -- Copy data into the table directly from the pgBackRest info command
     copy temp_pgbackrest_data (data)
         from program
             'pgbackrest --output=json info' (format text);
 
-    select temp_pgbackrest_data.data
+    select replace(temp_pgbackrest_data.data, E'\n', '\n')::jsonb
       into data
       from temp_pgbackrest_data;
 
