@@ -17,6 +17,10 @@ Backup constants
 #define BACKUP_PATH_HISTORY                                         "backup.history"
 #define BACKUP_BLOCK_INCR_EXT                                       ".pgbi"
 
+// Date and time must be in %Y%m%d-%H%M%S format, for example 20220901-193409
+#define DATE_TIME_REGEX                                             "[0-9]{8}\\-[0-9]{6}"
+#define DATE_TIME_LEN                                               (8 + 1 + 6)
+
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
