@@ -7,6 +7,6 @@ Stop Command
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
-void cmdStop(void);
+FN_EXTERN void cmdStop(void);
 
 #endif
