@@ -6,6 +6,7 @@ Local Command
 #include "command/archive/get/protocol.h"
 #include "command/archive/push/protocol.h"
 #include "command/backup/protocol.h"
+#include "command/local/local.h"
 #include "command/restore/protocol.h"
 #include "command/verify/protocol.h"
 #include "common/debug.h"
@@ -18,7 +19,7 @@ Local Command
 /***********************************************************************************************************************************
 Command handlers
 ***********************************************************************************************************************************/
-static const ProtocolServerHandler commandLocalHandlerList[] =
+static const ProtocolServerHandler commandLocalHandler[] =
 {
     PROTOCOL_SERVER_HANDLER_ARCHIVE_GET_LIST
     PROTOCOL_SERVER_HANDLER_ARCHIVE_PUSH_LIST
@@ -27,6 +28,8 @@ static const ProtocolServerHandler commandLocalHandlerList[] =
     PROTOCOL_SERVER_HANDLER_VERIFY_LIST
 };
 
+static const List *const commandLocalHandlerList = LSTDEF(commandLocalHandler);
+
 /**********************************************************************************************************************************/
 FN_EXTERN void
 cmdLocal(ProtocolServer *const server)
@@ -35,7 +38,7 @@ cmdLocal(ProtocolServer *const server)
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
-        protocolServerProcess(server, cfgCommandJobRetry(), commandLocalHandlerList, LENGTH_OF(commandLocalHandlerList));
+        protocolServerProcess(server, cfgCommandJobRetry(), commandLocalHandlerList);
     }
     MEM_CONTEXT_TEMP_END();
 
