@@ -50,7 +50,7 @@ typedef struct ManifestBlockDeltaBlock
 {
     uint64_t no;                                                    // Block number in the super block
     uint64_t offset;                                                // Offset into original file
-    unsigned char checksum[XX_HASH_SIZE_MAX];                       // Checksum of the block
+    uint8_t checksum[XX_HASH_SIZE_MAX];                             // Checksum of the block
 } ManifestBlockDeltaBlock;
 
 static List *
