@@ -7,6 +7,6 @@ Server Ping Command
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
-void cmdServerPing(void);
+FN_EXTERN void cmdServerPing(void);
 
 #endif
