@@ -91,7 +91,7 @@ bz2DecompressProcess(THIS_VOID, const Buffer *const compressed, Buffer *const un
         // bzip2 does not accept const input buffers
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wcast-qual"
-        this->stream.next_in = (char *)UNCONSTIFY(unsigned char *, bufPtrConst(compressed));
+        this->stream.next_in = (char *)UNCONSTIFY(uint8_t *, bufPtrConst(compressed));
 #pragma GCC diagnostic pop
     }
 
