@@ -16,6 +16,6 @@ Filter type constant
 /***********************************************************************************************************************************
 Constructors
 ***********************************************************************************************************************************/
-FN_EXTERN IoFilter *gzDecompressNew(void);
+FN_EXTERN IoFilter *gzDecompressNew(bool raw);
 
 #endif
