@@ -12,7 +12,6 @@ Compression Helper
 #include "common/compress/gz/compress.h"
 #include "common/compress/gz/decompress.h"
 #include "common/compress/helper.h"
-#include "common/compress/helper.intern.h"
 #include "common/compress/lz4/common.h"
 #include "common/compress/lz4/compress.h"
 #include "common/compress/lz4/decompress.h"
@@ -43,9 +42,6 @@ static const struct CompressHelperLocal
     IoFilter *(*compressNew)(int, bool);                            // Function to create new compression filter
     StringId decompressType;                                        // Type of the decompression filter
     IoFilter *(*decompressNew)(bool);                               // Function to create new decompression filter
-    int levelDefault : 8;                                           // Default compression level
-    int levelMin : 8;                                               // Minimum compression level
-    int levelMax : 8;                                               // Maximum compression level
 } compressHelperLocal[] =
 {
     {
@@ -61,9 +57,6 @@ static const struct CompressHelperLocal
         .compressNew = bz2CompressNew,
         .decompressType = BZ2_DECOMPRESS_FILTER_TYPE,
         .decompressNew = bz2DecompressNew,
-        .levelDefault = BZ2_COMPRESS_LEVEL_DEFAULT,
-        .levelMin = BZ2_COMPRESS_LEVEL_MIN,
-        .levelMax = BZ2_COMPRESS_LEVEL_MAX,
     },
     {
         .typeId = STRID5("gz", 0x3470),
@@ -73,9 +66,6 @@ static const struct CompressHelperLocal
         .compressNew = gzCompressNew,
         .decompressType = GZ_DECOMPRESS_FILTER_TYPE,
         .decompressNew = gzDecompressNew,
-        .levelDefault = GZ_COMPRESS_LEVEL_DEFAULT,
-        .levelMin = GZ_COMPRESS_LEVEL_MIN,
-        .levelMax = GZ_COMPRESS_LEVEL_MAX,
     },
     {
         .typeId = STRID6("lz4", 0x2068c1),
@@ -85,9 +75,6 @@ static const struct CompressHelperLocal
         .compressNew = lz4CompressNew,
         .decompressType = LZ4_DECOMPRESS_FILTER_TYPE,
         .decompressNew = lz4DecompressNew,
-        .levelDefault = LZ4_COMPRESS_LEVEL_DEFAULT,
-        .levelMin = LZ4_COMPRESS_LEVEL_MIN,
-        .levelMax = LZ4_COMPRESS_LEVEL_MAX,
     },
     {
         .typeId = STRID5("zst", 0x527a0),
@@ -98,9 +85,6 @@ static const struct CompressHelperLocal
         .compressNew = zstCompressNew,
         .decompressType = ZST_DECOMPRESS_FILTER_TYPE,
         .decompressNew = zstDecompressNew,
-        .levelDefault = ZST_COMPRESS_LEVEL_DEFAULT,
-        .levelMin = ZST_COMPRESS_LEVEL_MIN,
-        .levelMax = ZST_COMPRESS_LEVEL_MAX,
 #endif
     },
     {
@@ -185,48 +169,6 @@ compressTypeFromName(const String *const name)
     FUNCTION_TEST_RETURN(ENUM, result);
 }
 
-/**********************************************************************************************************************************/
-FN_EXTERN int
-compressLevelDefault(const CompressType type)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(ENUM, type);
-    FUNCTION_TEST_END();
-
-    ASSERT(type < LENGTH_OF(compressHelperLocal));
-    compressTypePresent(type);
-
-    FUNCTION_TEST_RETURN(INT, compressHelperLocal[type].levelDefault);
-}
-
-/**********************************************************************************************************************************/
-FN_EXTERN int
-compressLevelMin(const CompressType type)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(ENUM, type);
-    FUNCTION_TEST_END();
-
-    ASSERT(type < LENGTH_OF(compressHelperLocal));
-    compressTypePresent(type);
-
-    FUNCTION_TEST_RETURN(INT, compressHelperLocal[type].levelMin);
-}
-
-/**********************************************************************************************************************************/
-FN_EXTERN int
-compressLevelMax(const CompressType type)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(ENUM, type);
-    FUNCTION_TEST_END();
-
-    ASSERT(type < LENGTH_OF(compressHelperLocal));
-    compressTypePresent(type);
-
-    FUNCTION_TEST_RETURN(INT, compressHelperLocal[type].levelMax);
-}
-
 /**********************************************************************************************************************************/
 FN_EXTERN IoFilter *
 compressFilter(const CompressType type, const int level, const CompressFilterParam param)
