@@ -18,7 +18,7 @@ Filter type constant
 /***********************************************************************************************************************************
 Constructors
 ***********************************************************************************************************************************/
-IoFilter *zstDecompressNew(void);
+FN_EXTERN IoFilter *zstDecompressNew(bool raw);
 
 #endif
 
