@@ -12,13 +12,13 @@ HTTP Common
 Functions
 ***********************************************************************************************************************************/
 // Convert HTTP date to time_t and vice versa
-time_t httpDateToTime(const String *lastModified);
-String *httpDateFromTime(time_t time);
+FN_EXTERN time_t httpDateToTime(const String *lastModified);
+FN_EXTERN String *httpDateFromTime(time_t time);
 
 // Encode string to conform with URI specifications. If a path is being encoded then / characters won't be encoded.
-String *httpUriEncode(const String *uri, bool path);
+FN_EXTERN String *httpUriEncode(const String *uri, bool path);
 
 // Decode string that conforms to URI specifications
-String *httpUriDecode(const String *uri);
+FN_EXTERN String *httpUriDecode(const String *uri);
 
 #endif
