@@ -25,24 +25,24 @@ typedef struct IoCopyParam
 #define ioCopyP(source, destination, ...)                                                                                          \
     ioCopy(source, destination, (IoCopyParam){VAR_PARAM_INIT, __VA_ARGS__})
 
-void ioCopy(IoRead *source, IoWrite *destination, IoCopyParam param);
+FN_EXTERN void ioCopy(IoRead *source, IoWrite *destination, IoCopyParam param);
 
 // Read all IO into a buffer
-Buffer *ioReadBuf(IoRead *read);
+FN_EXTERN Buffer *ioReadBuf(IoRead *read);
 
 // Read all IO but don't store it. Useful for calculating checksums, size, etc.
-bool ioReadDrain(IoRead *read);
+FN_EXTERN bool ioReadDrain(IoRead *read);
 
 /***********************************************************************************************************************************
 Getters/Setters
 ***********************************************************************************************************************************/
 // Buffer size
-size_t ioBufferSize(void);
-void ioBufferSizeSet(size_t bufferSize);
+FN_EXTERN size_t ioBufferSize(void);
+FN_EXTERN void ioBufferSizeSet(size_t bufferSize);
 
 // I/O timeout in milliseconds. Used to timeout on connections and read/write operations. Note that an *entire* read/write operation
 // does not need to take place within this timeout but at least some progress needs to be made, even if it is only a byte.
-TimeMSec ioTimeoutMs(void);
-void ioTimeoutMsSet(TimeMSec timeout);
+FN_EXTERN TimeMSec ioTimeoutMs(void);
+FN_EXTERN void ioTimeoutMsSet(TimeMSec timeout);
 
 #endif
