@@ -15,15 +15,6 @@ Useful for converting non-string types (e.g. int) to strings for inclusion in me
 #define STRINGIFY_HELPER(param)                                     #param
 #define STRINGIFY(param)                                            STRINGIFY_HELPER(param)
 
-/***********************************************************************************************************************************
-Glue together a string/macro and another string//macro
-
-Useful for creating function names when one or both of the macro parameter needs to be converted to a macro before concatenating.
-common/type/object.h has numerous examples of this.
-***********************************************************************************************************************************/
-#define GLUE_HELPER(param1, param2)                                 param1##param2
-#define GLUE(param1, param2)                                        GLUE_HELPER(param1, param2)
-
 /***********************************************************************************************************************************
 If param2 > param1 then assign it to param1
 
