@@ -1,10 +1,10 @@
 /***********************************************************************************************************************************
 Memory Context Manager
 
-Memory is allocated inside contexts and all allocations (and child memory contexts) are freed when the context is freed.  The goal
+Memory is allocated inside contexts and all allocations (and child memory contexts) are freed when the context is freed. The goal
 is to make memory management both easier and more performant.
 
-Memory context management is encapsulated in macros so there is rarely any need to call the functions directly.  Memory allocations
+Memory context management is encapsulated in macros so there is rarely any need to call the functions directly. Memory allocations
 are mostly performed in the constructors of objects and reallocated as needed.
 
 See the sections on memory context management and memory allocations below for more details.
@@ -12,6 +12,7 @@ See the sections on memory context management and memory allocations below for m
 #ifndef COMMON_MEMCONTEXT_H
 #define COMMON_MEMCONTEXT_H
 
+#include <stdbool.h>
 #include <stddef.h>
 #include <stdint.h>
 
@@ -20,21 +21,20 @@ Memory context object
 ***********************************************************************************************************************************/
 typedef struct MemContext MemContext;
 
-#include "common/error.h"
 #include "common/type/param.h"
 
 /***********************************************************************************************************************************
 Define initial number of memory contexts
 
-No space is reserved for child contexts when a new context is created because most contexts will be leaves.  When a child context is
-requested then space will be reserved for this many child contexts initially.  When more space is needed the size will be doubled.
+No space is reserved for child contexts when a new context is created because most contexts will be leaves. When a child context is
+requested then space will be reserved for this many child contexts initially. When more space is needed the size will be doubled.
 ***********************************************************************************************************************************/
 #define MEM_CONTEXT_INITIAL_SIZE                                    4
 
 /***********************************************************************************************************************************
 Define initial number of memory allocations
 
-Space is reserved for this many allocations when a context is created.  When more space is needed the size will be doubled.
+Space is reserved for this many allocations when a context is created. When more space is needed the size will be doubled.
 ***********************************************************************************************************************************/
 #define MEM_CONTEXT_ALLOC_INITIAL_SIZE                              4
 
@@ -78,8 +78,8 @@ FN_EXTERN void *memNew(size_t size);
 // Allocate requested number of pointers and initialize them to NULL
 FN_EXTERN void *memNewPtrArray(size_t size);
 
-// Reallocate to the new size.  Original buffer pointer is undefined on return.
-FN_EXTERN void *memResize(const void *buffer, size_t size);
+// Reallocate to the new size. Original buffer pointer is undefined on return.
+FN_EXTERN void *memResize(void *buffer, size_t size);
 
 // Free memory allocation
 FN_EXTERN void memFree(void *buffer);
@@ -221,14 +221,14 @@ memContextSwitchBack();
 <The memory context must now be kept or discarded>
 memContextKeep()/memContextDiscard();
 
-There is no need to implement any error handling.  The mem context system will automatically clean up any mem contexts that were
+There is no need to implement any error handling. The mem context system will automatically clean up any mem contexts that were
 created but not marked as keep when an error occurs and reset the current mem context to whatever it was at the beginning of the
 nearest try block.
 
 Use the MEM_CONTEXT*() macros when possible rather than reimplement the boilerplate for every memory context block.
 ***********************************************************************************************************************************/
 // Create a new mem context in the current mem context. The new context must be either kept with memContextKeep() or discarded with
-// memContextDisard() before switching back from the parent context.
+// memContextDiscard() before switching back from the parent context.
 typedef struct MemContextNewParam
 {
     VAR_PARAM_HEADER;
@@ -283,8 +283,8 @@ FN_EXTERN void memContextMove(MemContext *this, MemContext *parentNew);
 // Set a function that will be called when this mem context is freed
 FN_EXTERN void memContextCallbackSet(MemContext *this, void (*callbackFunction)(void *), void *);
 
-// Clear the callback function so it won't be called when the mem context is freed.  This is usually done in the object free method
-// after resources have been freed but before memContextFree() is called.  The goal is to prevent the object free method from being
+// Clear the callback function so it won't be called when the mem context is freed. This is usually done in the object free method
+// after resources have been freed but before memContextFree() is called. The goal is to prevent the object free method from being
 // called more than once.
 FN_EXTERN void memContextCallbackClear(MemContext *this);
 
@@ -306,8 +306,8 @@ FN_EXTERN MemContext *memContextCurrent(void);
 // Prior context, i.e. the context that was current before the last memContextSwitch()
 FN_EXTERN MemContext *memContextPrior(void);
 
-// "top" context.  This context is created at initialization and is always present, i.e. it is never freed.  The top context is a
-// good place to put long-lived mem contexts since they won't be automatically freed until the program exits.
+// "top" context. This context is created at initialization and is always present, i.e. it is never freed. The top context is a good
+// place to put long-lived mem contexts since they won't be automatically freed until the program exits.
 FN_EXTERN MemContext *memContextTop(void);
 
 // Get total size of mem context and all children
@@ -326,7 +326,7 @@ Macros for function logging
 /***********************************************************************************************************************************
 Internal functions
 ***********************************************************************************************************************************/
-// Clean up mem contexts after an error.  Should only be called from error handling routines.
+// Clean up mem contexts after an error. Should only be called from error handling routines.
 FN_EXTERN void memContextClean(unsigned int tryDepth, bool fatal);
 
 #endif
