@@ -287,7 +287,7 @@ strIdToZN(StringId strId, char *const buffer)
         case stringIdBit5:
         {
             // Map to convert encoding to characters
-            static const char map[32] = "!abcdefghijklmnopqrstuvwxyz-256!";
+            VR_NON_STRING static const char map[32] = "!abcdefghijklmnopqrstuvwxyz-256!";
 
             // Macro to decode all but the last character
             #define STR5ID_TO_ZN_IDX(idx)                                                                                          \
@@ -330,7 +330,7 @@ strIdToZN(StringId strId, char *const buffer)
             ASSERT(bit == stringIdBit6);
 
             // Map to convert encoding to characters
-            static const char map[64] = "!abcdefghijklmnopqrstuvwxyz-0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ";
+            VR_NON_STRING static const char map[64] = "!abcdefghijklmnopqrstuvwxyz-0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ";
 
             // Macro to decode all but the last character
             #define STR6ID_TO_ZN_IDX(idx)                                                                                          \
