@@ -155,11 +155,11 @@ cfgCommandParam(void)
 
 /**********************************************************************************************************************************/
 FN_EXTERN const String *
-cfgExe(void)
+cfgBin(void)
 {
     FUNCTION_TEST_VOID();
     ASSERT(cfgInited());
-    FUNCTION_TEST_RETURN(STRING, configLocal->exe);
+    FUNCTION_TEST_RETURN(STRING, configLocal->bin);
 }
 
 /**********************************************************************************************************************************/
@@ -410,61 +410,20 @@ cfgOptionIdxTotal(const ConfigOption optionId)
 
 /**********************************************************************************************************************************/
 FN_EXTERN const String *
-cfgOptionDefault(const ConfigOption optionId)
+cfgOptionIdxDefaultValue(const ConfigOption optionId, const unsigned int optionIdx)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, optionId);
+        FUNCTION_TEST_PARAM(UINT, optionIdx);
     FUNCTION_TEST_END();
 
     ASSERT(cfgInited());
     ASSERT(optionId < CFG_OPTION_TOTAL);
+    ASSERT_DECLARE(const bool group = configLocal->option[optionId].group);
+    ASSERT_DECLARE(const unsigned int indexTotal = configLocal->optionGroup[configLocal->option[optionId].groupId].indexTotal);
+    ASSERT((!group && optionIdx == 0) || (group && optionIdx < indexTotal));
 
-    ConfigOptionData *const option = &configLocal->option[optionId];
-
-    if (option->defaultValue == NULL)
-        option->defaultValue = cfgParseOptionDefault(cfgCommand(), optionId);
-
-    FUNCTION_TEST_RETURN_CONST(STRING, option->defaultValue);
-}
-
-FN_EXTERN void
-cfgOptionDefaultSet(const ConfigOption optionId, const Variant *defaultValue)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(ENUM, optionId);
-        FUNCTION_TEST_PARAM(VARIANT, defaultValue);
-    FUNCTION_TEST_END();
-
-    ASSERT(optionId < CFG_OPTION_TOTAL);
-    ASSERT(cfgInited());
-    ASSERT(configLocal->option[optionId].valid);
-    ASSERT(cfgParseOptionDataType(optionId) == cfgOptDataTypeString);
-
-    MEM_CONTEXT_BEGIN(configLocal->memContext)
-    {
-        // Duplicate into this context
-        defaultValue = varDup(defaultValue);
-
-        // Set the default value
-        ConfigOptionData *const option = &configLocal->option[optionId];
-        option->defaultValue = varStr(defaultValue);
-
-        // Copy the value to option indexes that are marked as default so the default can be retrieved quickly
-        for (unsigned int optionIdx = 0; optionIdx < cfgOptionIdxTotal(optionId); optionIdx++)
-        {
-            ConfigOptionValue *const optionValue = &option->index[optionIdx];
-
-            if (optionValue->source == cfgSourceDefault)
-            {
-                optionValue->set = true;
-                optionValue->value.string = varStr(defaultValue);
-                optionValue->display = NULL;
-            }
-        }
-    }
-    MEM_CONTEXT_END();
-
-    FUNCTION_TEST_RETURN_VOID();
+    FUNCTION_TEST_RETURN_CONST(STRING, configLocal->option[optionId].index[optionIdx].defaultValue);
 }
 
 /**********************************************************************************************************************************/
@@ -489,7 +448,7 @@ cfgOptionDisplayVar(const Variant *const value, const ConfigOptionType optionTyp
     }
     else if (optionType == cfgOptTypeTime)
     {
-        FUNCTION_TEST_RETURN_CONST(STRING, strNewDbl((double)varInt64(value) / MSEC_PER_SEC));
+        FUNCTION_TEST_RETURN_CONST(STRING, strNewDivP(varUInt64Force(value), MSEC_PER_SEC, .precision = 3, .trim = true));
     }
     else if (optionType == cfgOptTypeStringId)
     {
@@ -967,6 +926,21 @@ cfgOptionIdxSet(
         optionValueType->string = NULL;
     }
 
+    // Set the default when specified
+    if (source == cfgSourceDefault)
+    {
+        if (value != NULL)
+        {
+            MEM_CONTEXT_BEGIN(configLocal->memContext)
+            {
+                optionValue->defaultValue = cfgOptionDisplayVar(value, cfgParseOptionType(optionId));
+            }
+            MEM_CONTEXT_END();
+        }
+        else
+            optionValue->defaultValue = NULL;
+    }
+
     // Clear the display value, which will be generated when needed
     optionValue->display = NULL;
 
