@@ -102,7 +102,7 @@ protocolClientSessionFindIdx(const ProtocolClient *const this, const uint64_t se
 }
 
 /**********************************************************************************************************************************/
-FN_EXTERN void
+static void
 protocolClientRequestInternal(ProtocolClientSession *const this, const ProtocolCommandType type, PackWrite *const param)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
@@ -270,7 +270,7 @@ protocolClientResponseInternal(ProtocolClientSession *const this)
         protocolClientError(this->client, type, packRead);
         CHECK(FormatError, type == protocolMessageTypeResponse, "expected response message");
 
-        // Return result the the caller
+        // Return result to the caller
         result = objMove(packRead, memContextPrior());
     }
     MEM_CONTEXT_TEMP_END();
