@@ -192,20 +192,17 @@ protocolServerRequest(ProtocolServer *const this)
 
 /**********************************************************************************************************************************/
 FN_EXTERN void
-protocolServerProcess(
-    ProtocolServer *const this, const VariantList *const retryInterval, const ProtocolServerHandler *const handlerList,
-    const unsigned int handlerListSize)
+protocolServerProcess(ProtocolServer *const this, const VariantList *const retryInterval, const List *const handlerList)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(PROTOCOL_SERVER, this);
         FUNCTION_LOG_PARAM(VARIANT_LIST, retryInterval);
-        FUNCTION_LOG_PARAM_P(VOID, handlerList);
-        FUNCTION_LOG_PARAM(UINT, handlerListSize);
+        FUNCTION_LOG_PARAM(LIST, handlerList);
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
     ASSERT(handlerList != NULL);
-    ASSERT(handlerListSize > 0);
+    ASSERT(!lstEmpty(handlerList));
 
     // Loop until exit request is received
     bool exit = false;
@@ -222,11 +219,13 @@ protocolServerProcess(
                 // Find the handler
                 const ProtocolServerHandler *handler = NULL;
 
-                for (unsigned int handlerIdx = 0; handlerIdx < handlerListSize; handlerIdx++)
+                for (unsigned int handlerIdx = 0; handlerIdx < lstSize(handlerList); handlerIdx++)
                 {
-                    if (request.id == handlerList[handlerIdx].command)
+                    const ProtocolServerHandler *const handlerMatch = lstGet(handlerList, handlerIdx);
+
+                    if (request.id == handlerMatch->command)
                     {
-                        handler = &handlerList[handlerIdx];
+                        handler = handlerMatch;
                         break;
                     }
                 }
