@@ -385,13 +385,14 @@ storageRepoGet(const unsigned int repoIdx, const bool write)
             }
         }
 
-        // If no helper was found it try Posix
+        // If no helper was found then try Posix
         if (result == NULL)
         {
             CHECK(AssertError, type == STORAGE_POSIX_TYPE, "invalid storage type");
 
             result = storagePosixNewP(
-                cfgOptionIdxStr(cfgOptRepoPath, repoIdx), .write = write, .pathExpressionFunction = storageRepoPathExpression);
+                cfgOptionIdxStr(cfgOptRepoPath, repoIdx), .write = write, .pathExpressionFunction = storageRepoPathExpression,
+                .noSymLink = cfgOptionValid(cfgOptRepoSymlink) ? !cfgOptionIdxBool(cfgOptRepoSymlink, repoIdx) : true);
         }
     }
 
