@@ -11,16 +11,19 @@ Remote Storage Protocol Handler
 Functions
 ***********************************************************************************************************************************/
 // Process storage protocol requests
-FN_EXTERN void storageRemoteFeatureProtocol(PackRead *param, ProtocolServer *server);
-FN_EXTERN void storageRemoteInfoProtocol(PackRead *param, ProtocolServer *server);
-FN_EXTERN void storageRemoteLinkCreateProtocol(PackRead *param, ProtocolServer *server);
-FN_EXTERN void storageRemoteListProtocol(PackRead *param, ProtocolServer *server);
-FN_EXTERN void storageRemoteOpenReadProtocol(PackRead *param, ProtocolServer *server);
-FN_EXTERN void storageRemoteOpenWriteProtocol(PackRead *param, ProtocolServer *server);
-FN_EXTERN void storageRemotePathCreateProtocol(PackRead *param, ProtocolServer *server);
-FN_EXTERN void storageRemotePathRemoveProtocol(PackRead *param, ProtocolServer *server);
-FN_EXTERN void storageRemotePathSyncProtocol(PackRead *param, ProtocolServer *server);
-FN_EXTERN void storageRemoteRemoveProtocol(PackRead *param, ProtocolServer *server);
+FN_EXTERN ProtocolServerResult *storageRemoteFeatureProtocol(PackRead *param);
+FN_EXTERN ProtocolServerResult *storageRemoteInfoProtocol(PackRead *param);
+FN_EXTERN ProtocolServerResult *storageRemoteLinkCreateProtocol(PackRead *param);
+FN_EXTERN ProtocolServerResult *storageRemoteListProtocol(PackRead *param);
+FN_EXTERN ProtocolServerResult *storageRemotePathCreateProtocol(PackRead *param);
+FN_EXTERN ProtocolServerResult *storageRemotePathRemoveProtocol(PackRead *param);
+FN_EXTERN ProtocolServerResult *storageRemotePathSyncProtocol(PackRead *param);
+FN_EXTERN ProtocolServerResult *storageRemoteReadOpenProtocol(PackRead *param);
+FN_EXTERN ProtocolServerResult *storageRemoteReadProtocol(PackRead *param, void *fileRead);
+FN_EXTERN ProtocolServerResult *storageRemoteRemoveProtocol(PackRead *param);
+FN_EXTERN ProtocolServerResult *storageRemoteWriteOpenProtocol(PackRead *param);
+FN_EXTERN ProtocolServerResult *storageRemoteWriteProtocol(PackRead *param, void *fileWrite);
+FN_EXTERN ProtocolServerResult *storageRemoteWriteCloseProtocol(PackRead *param, void *fileWrite);
 
 /***********************************************************************************************************************************
 Protocol commands for ProtocolServerHandler arrays passed to protocolServerProcess()
@@ -29,24 +32,25 @@ Protocol commands for ProtocolServerHandler arrays passed to protocolServerProce
 #define PROTOCOL_COMMAND_STORAGE_INFO                               STRID5("s-i", 0x27730)
 #define PROTOCOL_COMMAND_STORAGE_LINK_CREATE                        STRID5("s-lc", 0x1b3730)
 #define PROTOCOL_COMMAND_STORAGE_LIST                               STRID5("s-l", 0x33730)
-#define PROTOCOL_COMMAND_STORAGE_OPEN_READ                          STRID5("s-or", 0x93f730)
-#define PROTOCOL_COMMAND_STORAGE_OPEN_WRITE                         STRID5("s-ow", 0xbbf730)
 #define PROTOCOL_COMMAND_STORAGE_PATH_CREATE                        STRID5("s-pc", 0x1c3730)
-#define PROTOCOL_COMMAND_STORAGE_REMOVE                             STRID5("s-r", 0x4b730)
 #define PROTOCOL_COMMAND_STORAGE_PATH_REMOVE                        STRID5("s-pr", 0x943730)
 #define PROTOCOL_COMMAND_STORAGE_PATH_SYNC                          STRID5("s-ps", 0x9c3730)
+#define PROTOCOL_COMMAND_STORAGE_READ                               STRID5("s-rd", 0x24b730)
+#define PROTOCOL_COMMAND_STORAGE_REMOVE                             STRID5("s-r", 0x4b730)
+#define PROTOCOL_COMMAND_STORAGE_WRITE                              STRID5("s-wr", 0x95f730)
 
 #define PROTOCOL_SERVER_HANDLER_STORAGE_REMOTE_LIST                                                                                \
-    {.command = PROTOCOL_COMMAND_STORAGE_FEATURE, .handler = storageRemoteFeatureProtocol},                                        \
-    {.command = PROTOCOL_COMMAND_STORAGE_INFO, .handler = storageRemoteInfoProtocol},                                              \
-    {.command = PROTOCOL_COMMAND_STORAGE_LINK_CREATE, .handler = storageRemoteLinkCreateProtocol},                                 \
-    {.command = PROTOCOL_COMMAND_STORAGE_LIST, .handler = storageRemoteListProtocol},                                              \
-    {.command = PROTOCOL_COMMAND_STORAGE_OPEN_READ, .handler = storageRemoteOpenReadProtocol},                                     \
-    {.command = PROTOCOL_COMMAND_STORAGE_OPEN_WRITE, .handler = storageRemoteOpenWriteProtocol},                                   \
-    {.command = PROTOCOL_COMMAND_STORAGE_PATH_CREATE, .handler = storageRemotePathCreateProtocol},                                 \
-    {.command = PROTOCOL_COMMAND_STORAGE_PATH_REMOVE, .handler = storageRemotePathRemoveProtocol},                                 \
-    {.command = PROTOCOL_COMMAND_STORAGE_PATH_SYNC, .handler = storageRemotePathSyncProtocol},                                     \
-    {.command = PROTOCOL_COMMAND_STORAGE_REMOVE, .handler = storageRemoteRemoveProtocol},
+    {.command = PROTOCOL_COMMAND_STORAGE_FEATURE, .process = storageRemoteFeatureProtocol},                                        \
+    {.command = PROTOCOL_COMMAND_STORAGE_INFO, .process = storageRemoteInfoProtocol},                                              \
+    {.command = PROTOCOL_COMMAND_STORAGE_LINK_CREATE, .process = storageRemoteLinkCreateProtocol},                                 \
+    {.command = PROTOCOL_COMMAND_STORAGE_LIST, .process = storageRemoteListProtocol},                                              \
+    {.command = PROTOCOL_COMMAND_STORAGE_PATH_CREATE, .process = storageRemotePathCreateProtocol},                                 \
+    {.command = PROTOCOL_COMMAND_STORAGE_PATH_REMOVE, .process = storageRemotePathRemoveProtocol},                                 \
+    {.command = PROTOCOL_COMMAND_STORAGE_PATH_SYNC, .process = storageRemotePathSyncProtocol},                                     \
+    {.command = PROTOCOL_COMMAND_STORAGE_READ, .open = storageRemoteReadOpenProtocol, .processSession = storageRemoteReadProtocol},\
+    {.command = PROTOCOL_COMMAND_STORAGE_REMOVE, .process = storageRemoteRemoveProtocol},                                          \
+    {.command = PROTOCOL_COMMAND_STORAGE_WRITE, .open = storageRemoteWriteOpenProtocol,                                            \
+        .processSession = storageRemoteWriteProtocol, .close = storageRemoteWriteCloseProtocol},
 
 /***********************************************************************************************************************************
 Filters that may be passed to a remote
@@ -61,6 +65,6 @@ typedef struct StorageRemoteFilterHandler
     StorageRemoteFilterHandlerNoParam handlerNoParam;               // Handler with no parameters
 } StorageRemoteFilterHandler;
 
-FN_EXTERN void storageRemoteFilterHandlerSet(const StorageRemoteFilterHandler *filterHandler, unsigned int filterHandlerSize);
+FN_EXTERN void storageRemoteFilterHandlerSet(const List *filterHandler);
 
 #endif
