@@ -970,8 +970,7 @@ storageSftpNewWrite(THIS_VOID, const String *const file, const StorageInterfaceN
         STORAGE_WRITE,
         storageWriteSftpNew(
             this, file, this->session, this->sftpSession, this->sftpHandle, param.modeFile, param.modePath, param.user, param.group,
-            param.timeModified, param.createPath, param.syncFile, this->interface.pathSync != NULL ? param.syncPath : false,
-            param.atomic, param.truncate));
+            param.timeModified, param.createPath, param.syncFile, param.atomic, param.truncate));
 }
 
 /**********************************************************************************************************************************/
