@@ -40,10 +40,10 @@ Functions
 bool testBegin(const char *name);
 
 // Read a file (max 256k) into a buffer
-void hrnFileRead(const char *fileName, unsigned char *buffer, size_t bufferSize);
+void hrnFileRead(const char *fileName, uint8_t *buffer, size_t bufferSize);
 
 // Write a buffer to a file
-void hrnFileWrite(const char *fileName, const unsigned char *buffer, size_t bufferSize);
+void hrnFileWrite(const char *fileName, const uint8_t *buffer, size_t bufferSize);
 
 // Diff two strings using command-line diff tool
 const char *hrnDiff(const char *actual, const char *expected);
@@ -136,6 +136,63 @@ Test that an expected error is actually thrown and error when it isn't
     FUNCTION_HARNESS_STACK_TRACE_LINE_SET(0);                                                                                      \
 }
 
+/***********************************************************************************************************************************
+Test that an expected error is actually thrown and error when it isn't
+***********************************************************************************************************************************/
+#define TEST_ERROR_MULTI(statement, errorTypeExpected, ...)                                                                        \
+{                                                                                                                                  \
+    const char *const errorMessageExpected[] = {__VA_ARGS__};                                                                      \
+    bool TEST_ERROR_catch = false;                                                                                                 \
+                                                                                                                                   \
+    /* Set the line number for the current function in the stack trace */                                                          \
+    FUNCTION_HARNESS_STACK_TRACE_LINE_SET(__LINE__);                                                                               \
+                                                                                                                                   \
+    hrnTestLogPrefix(__LINE__);                                                                                                    \
+    printf("expect %s: [%s]\n", errorTypeName(&errorTypeExpected), #__VA_ARGS__);                                                  \
+    fflush(stdout);                                                                                                                \
+                                                                                                                                   \
+    TEST_ERROR_MEM_CONTEXT_BEGIN()                                                                                                 \
+    {                                                                                                                              \
+        TRY_BEGIN()                                                                                                                \
+        {                                                                                                                          \
+            statement;                                                                                                             \
+        }                                                                                                                          \
+        CATCH_FATAL()                                                                                                              \
+        {                                                                                                                          \
+            TEST_ERROR_catch = true;                                                                                               \
+            bool match = false;                                                                                                    \
+                                                                                                                                   \
+            if (errorType() == &errorTypeExpected)                                                                                 \
+            {                                                                                                                      \
+                for (unsigned int errorIdx = 0; errorIdx < LENGTH_OF(errorMessageExpected); errorIdx++)                            \
+                {                                                                                                                  \
+                    if (strcmp(errorMessage(), errorMessageExpected[errorIdx]) == 0)                                               \
+                    {                                                                                                              \
+                        match = true;                                                                                              \
+                        break;                                                                                                     \
+                    }                                                                                                              \
+                }                                                                                                                  \
+            }                                                                                                                      \
+                                                                                                                                   \
+            if (!match)                                                                                                            \
+            {                                                                                                                      \
+                THROW_FMT(                                                                                                         \
+                    TestError, "EXPECTED %s: [%s]\n\n BUT GOT %s: %s\n\nTHROWN AT:\n%s", errorTypeName(&errorTypeExpected),        \
+                    #__VA_ARGS__, errorName(), errorMessage(), errorStackTrace());                                                 \
+            }                                                                                                                      \
+        }                                                                                                                          \
+        TRY_END();                                                                                                                 \
+    }                                                                                                                              \
+    TEST_ERROR_MEM_CONTEXT_END();                                                                                                  \
+                                                                                                                                   \
+    if (!TEST_ERROR_catch)                                                                                                         \
+        THROW_FMT(                                                                                                                 \
+            TestError, "statement '%s' returned but error %s, [%s] was expected", #statement, errorTypeName(&errorTypeExpected),   \
+            #__VA_ARGS__);                                                                                                         \
+                                                                                                                                   \
+    FUNCTION_HARNESS_STACK_TRACE_LINE_SET(0);                                                                                      \
+}
+
 /***********************************************************************************************************************************
 Test error with a formatted expected message
 ***********************************************************************************************************************************/
@@ -422,6 +479,6 @@ Is this a 64-bit system? If not then it is 32-bit since 16-bit systems are not s
 /***********************************************************************************************************************************
 Is this a big-endian system?
 ***********************************************************************************************************************************/
-#define TEST_BIG_ENDIAN() (!*(unsigned char *)&(uint16_t){1})
+#define TEST_BIG_ENDIAN() (!*(uint8_t *)&(uint16_t){1})
 
 #endif
