@@ -98,7 +98,7 @@ testRun(void)
 
         // Install local command handler shim
         static const ProtocolServerHandler testLocalHandlerList[] = {PROTOCOL_SERVER_HANDLER_ARCHIVE_GET_LIST};
-        hrnProtocolLocalShimInstall(testLocalHandlerList, LENGTH_OF(testLocalHandlerList));
+        hrnProtocolLocalShimInstall(LSTDEF(testLocalHandlerList));
 
         // Arguments that must be included
         StringList *argBaseList = strLstNew();
