@@ -25,7 +25,7 @@ testFunction2(void)
 
 static int
 testFunction1(
-    int paramInt, bool paramBool, bool *paramBoolP, bool **paramBoolPP, void *paramVoidP, double paramDouble, mode_t paramMode)
+    int paramInt, bool paramBool, bool *paramBoolP, bool **paramBoolPP, void *paramVoidP, mode_t paramMode)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(INT, paramInt);
@@ -33,7 +33,6 @@ testFunction1(
         FUNCTION_LOG_PARAM_P(BOOL, paramBoolP);
         FUNCTION_LOG_PARAM_PP(BOOL, paramBoolPP);
         FUNCTION_LOG_PARAM_P(VOID, paramVoidP);
-        FUNCTION_LOG_PARAM(DOUBLE, paramDouble);
         FUNCTION_LOG_PARAM(MODE, paramMode);
     FUNCTION_LOG_END();
 
@@ -185,11 +184,11 @@ testRun(void)
     if (testBegin("FUNCTION_DEBUG() and FUNCTION_LOG_RETURN()"))
     {
         harnessLogLevelSet(logLevelTrace);
-        testFunction1(99, false, NULL, NULL, NULL, 1.17, 0755);
+        testFunction1(99, false, NULL, NULL, NULL, 0755);
 
         TEST_RESULT_LOG(
             "P00  DEBUG:     " TEST_PGB_PATH "/test/src/module/common/debugOnTest::testFunction1: (paramInt: 99, paramBool: false,"
-            " paramBoolP: null, paramBoolPP: null, paramVoidP: null, paramDouble: 1.17, paramMode: 0755)\n"
+            " paramBoolP: null, paramBoolPP: null, paramVoidP: null, paramMode: 0755)\n"
             "P00  TRACE:         " TEST_PGB_PATH "/test/src/module/common/debugOnTest::testFunction2: (void)\n"
             "P00  TRACE:         " TEST_PGB_PATH "/test/src/module/common/debugOnTest::testFunction2: => void\n"
             "P00  DEBUG:     " TEST_PGB_PATH "/test/src/module/common/debugOnTest::testFunction1: => 1");
@@ -200,11 +199,11 @@ testRun(void)
         bool **testBoolPP = &testBoolP;
         void *testVoidP = NULL;
 
-        testFunction1(99, false, testBoolP, testBoolPP, testVoidP, 1.17, 0755);
+        testFunction1(99, false, testBoolP, testBoolPP, testVoidP, 0755);
 
         TEST_RESULT_LOG(
             "P00  DEBUG:     " TEST_PGB_PATH "/test/src/module/common/debugOnTest::testFunction1: (paramInt: 99, paramBool: false,"
-            " paramBoolP: *true, paramBoolPP: **true, paramVoidP: null, paramDouble: 1.17, paramMode: 0755)\n"
+            " paramBoolP: *true, paramBoolPP: **true, paramVoidP: null, paramMode: 0755)\n"
             "P00  TRACE:         " TEST_PGB_PATH "/test/src/module/common/debugOnTest::testFunction2: (void)\n"
             "P00  TRACE:         " TEST_PGB_PATH "/test/src/module/common/debugOnTest::testFunction2: => void\n"
             "P00  DEBUG:     " TEST_PGB_PATH "/test/src/module/common/debugOnTest::testFunction1: => 1");
@@ -212,18 +211,18 @@ testRun(void)
         testBoolP = NULL;
         testVoidP = (void *)1;
 
-        testFunction1(99, false, testBoolP, testBoolPP, testVoidP, 1.17, 0755);
+        testFunction1(99, false, testBoolP, testBoolPP, testVoidP, 0755);
 
         TEST_RESULT_LOG(
             "P00  DEBUG:     " TEST_PGB_PATH "/test/src/module/common/debugOnTest::testFunction1: (paramInt: 99, paramBool: false,"
-            " paramBoolP: null, paramBoolPP: *null, paramVoidP: *void, paramDouble: 1.17, paramMode: 0755)\n"
+            " paramBoolP: null, paramBoolPP: *null, paramVoidP: *void, paramMode: 0755)\n"
             "P00  TRACE:         " TEST_PGB_PATH "/test/src/module/common/debugOnTest::testFunction2: (void)\n"
             "P00  TRACE:         " TEST_PGB_PATH "/test/src/module/common/debugOnTest::testFunction2: => void\n"
             "P00  DEBUG:     " TEST_PGB_PATH "/test/src/module/common/debugOnTest::testFunction1: => 1");
 
         // -------------------------------------------------------------------------------------------------------------------------
         harnessLogLevelReset();
-        testFunction1(55, true, NULL, NULL, NULL, 0.99, 0755);
+        testFunction1(55, true, NULL, NULL, NULL, 0755);
 
         TEST_RESULT_LOG("");
     }
