@@ -83,7 +83,7 @@ testRun(void)
                     HRN_PQ_SCRIPT_OPEN(1, "dbname='testdb' port=5432"),
                     HRN_PQ_SCRIPT_SET_SEARCH_PATH(1),
                     HRN_PQ_SCRIPT_SET_CLIENT_ENCODING(1),
-                    HRN_PQ_SCRIPT_VALIDATE_QUERY(1, PG_VERSION_94, TEST_PATH "/pg", NULL, NULL),
+                    HRN_PQ_SCRIPT_VALIDATE_QUERY(1, PG_VERSION_95, TEST_PATH "/pg", NULL, NULL),
                     HRN_PQ_SCRIPT_SET_APPLICATION_NAME(1),
                     HRN_PQ_SCRIPT_IS_STANDBY_QUERY(1, false),
                     HRN_PQ_SCRIPT_CLOSE(1),
@@ -91,7 +91,7 @@ testRun(void)
                     HRN_PQ_SCRIPT_OPEN(1, "dbname='testdb' port=5432"),
                     HRN_PQ_SCRIPT_SET_SEARCH_PATH(1),
                     HRN_PQ_SCRIPT_SET_CLIENT_ENCODING(1),
-                    HRN_PQ_SCRIPT_VALIDATE_QUERY(1, PG_VERSION_94, TEST_PATH "/pg", NULL, NULL),
+                    HRN_PQ_SCRIPT_VALIDATE_QUERY(1, PG_VERSION_95, TEST_PATH "/pg", NULL, NULL),
                     HRN_PQ_SCRIPT_SET_APPLICATION_NAME(1),
                     HRN_PQ_SCRIPT_IS_STANDBY_QUERY(1, false),
                     HRN_PQ_SCRIPT_CREATE_RESTORE_POINT(1, "2/3"),
@@ -113,8 +113,7 @@ testRun(void)
                     PROTOCOL_SERVER_HANDLER_STORAGE_REMOTE_LIST
                 };
 
-                TEST_RESULT_VOID(
-                    protocolServerProcess(server, NULL, commandHandler, LENGTH_OF(commandHandler)), "run process loop");
+                TEST_RESULT_VOID(protocolServerProcess(server, NULL, LSTDEF(commandHandler)), "run process loop");
                 TEST_RESULT_VOID(protocolServerFree(server), "free server");
             }
             HRN_FORK_CHILD_END();
@@ -130,7 +129,7 @@ testRun(void)
                 HRN_CFG_LOAD(cfgCmdBackup, argList);
 
                 // Create control file
-                HRN_PG_CONTROL_PUT(storagePgIdxWrite(0), PG_VERSION_94);
+                HRN_PG_CONTROL_PUT(storagePgIdxWrite(0), PG_VERSION_95);
 
                 // Create client
                 ProtocolClient *client = NULL;
@@ -151,7 +150,6 @@ testRun(void)
                     TRY_BEGIN()
                     {
                         TEST_RESULT_VOID(dbOpen(db), "open db");
-                        TEST_RESULT_UINT(db->remoteIdx, 0, "check remote idx");
                         TEST_RESULT_VOID(dbFree(db), "free db");
                         db = NULL;
                     }
@@ -170,7 +168,6 @@ testRun(void)
                     TRY_BEGIN()
                     {
                         TEST_RESULT_VOID(dbOpen(db), "open db");
-                        TEST_RESULT_UINT(db->remoteIdx, 1, "check idx");
                         TEST_RESULT_STR_Z(dbWalSwitch(db), "000000030000000200000003", "wal switch");
                         TEST_RESULT_UINT(dbDbTimeout(db), 777000, "check timeout");
                         TEST_RESULT_VOID(memContextCallbackClear(db->pub.memContext), "clear context so close is not called");
@@ -206,7 +203,7 @@ testRun(void)
         HRN_CFG_LOAD(cfgCmdBackup, argList);
 
         // Create control file
-        HRN_PG_CONTROL_PUT(storagePgIdxWrite(0), PG_VERSION_94, .checkpoint = pgLsnFromStr(STRDEF("1/1")));
+        HRN_PG_CONTROL_PUT(storagePgIdxWrite(0), PG_VERSION_95, .checkpoint = pgLsnFromStr(STRDEF("1/1")));
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("error when unable to select any pg_settings");
@@ -250,7 +247,7 @@ testRun(void)
             HRN_PQ_SCRIPT_CLOSE(1));
 
         TEST_ERROR(
-            dbGet(true, true, false), DbConnectError,
+            dbGet(true, true, CFGOPTVAL_BACKUP_STANDBY_N), DbConnectError,
             "unable to find primary cluster - cannot proceed\n"
             "HINT: are all available clusters in recovery?");
 
@@ -269,7 +266,7 @@ testRun(void)
             HRN_PQ_SCRIPT_OPEN_GE_93(1, "dbname='backupdb' port=5432", PG_VERSION_95, TEST_PATH "/pg1", false, NULL, NULL));
 
         DbGetResult db = {0};
-        TEST_ASSIGN(db, dbGet(true, true, false), "get primary");
+        TEST_ASSIGN(db, dbGet(true, true, CFGOPTVAL_BACKUP_STANDBY_N), "get primary");
 
         // Get start time
         HRN_PQ_SCRIPT_SET(HRN_PQ_SCRIPT_TIME_QUERY(1, 1000));
@@ -298,7 +295,7 @@ testRun(void)
         HRN_PQ_SCRIPT_SET(HRN_PQ_SCRIPT_DATABASE_LIST_1(1, "test1"));
         TEST_RESULT_STR_Z(hrnPackToStr(dbList(db.primary)), "1:array:[1:u32:16384, 2:str:test1, 3:u32:13777]", "check db list");
 
-        // Get tablespace ist
+        // Get tablespace list
         HRN_PQ_SCRIPT_SET(HRN_PQ_SCRIPT_TABLESPACE_LIST_0(1));
         TEST_RESULT_STR_Z(hrnPackToStr(dbTablespaceList(db.primary)), "", "check tablespace list");
 
@@ -325,7 +322,7 @@ testRun(void)
         HRN_PQ_SCRIPT_SET(
             HRN_PQ_SCRIPT_OPEN_GE_93(1, "dbname='backupdb' port=5432", PG_VERSION_95, TEST_PATH "/pg1", false, NULL, NULL));
 
-        TEST_ASSIGN(db, dbGet(true, true, false), "get primary");
+        TEST_ASSIGN(db, dbGet(true, true, CFGOPTVAL_BACKUP_STANDBY_N), "get primary");
 
         // Start backup when backup is in progress
         HRN_PQ_SCRIPT_SET(
@@ -361,7 +358,7 @@ testRun(void)
         HRN_PQ_SCRIPT_SET(
             HRN_PQ_SCRIPT_OPEN_GE_96(1, "dbname='backupdb' port=5432", PG_VERSION_96, TEST_PATH "/pg1", false, NULL, NULL));
 
-        TEST_ASSIGN(db, dbGet(true, true, false), "get primary");
+        TEST_ASSIGN(db, dbGet(true, true, CFGOPTVAL_BACKUP_STANDBY_N), "get primary");
 
         // Start backup with timeline error
         HRN_PQ_SCRIPT_SET(
@@ -423,7 +420,7 @@ testRun(void)
             HRN_PQ_SCRIPT_OPEN_GE_93(1, "dbname='postgres' port=5432", PG_VERSION_95, TEST_PATH "/pg1", false, NULL, NULL),
             HRN_PQ_SCRIPT_OPEN_GE_93(2, "dbname='postgres' port=5433", PG_VERSION_95, TEST_PATH "/pg2", true, NULL, NULL));
 
-        TEST_ASSIGN(db, dbGet(false, true, true), "get primary and standby");
+        TEST_ASSIGN(db, dbGet(false, true, CFGOPTVAL_BACKUP_STANDBY_Y), "get primary and standby");
 
         // Start backup
         HRN_PQ_SCRIPT_SET(
@@ -484,7 +481,7 @@ testRun(void)
             HRN_PQ_SCRIPT_OPEN_GE_96(1, "dbname='postgres' port=5432", PG_VERSION_10, TEST_PATH "/pg1", false, NULL, NULL),
             HRN_PQ_SCRIPT_OPEN_GE_96(2, "dbname='postgres' port=5433", PG_VERSION_10, TEST_PATH "/pg2", true, NULL, NULL));
 
-        TEST_ASSIGN(db, dbGet(false, true, true), "get primary and standby");
+        TEST_ASSIGN(db, dbGet(false, true, CFGOPTVAL_BACKUP_STANDBY_Y), "get primary and standby");
 
         TEST_RESULT_UINT(dbPgControl(db.primary).timeline, 5, "check primary timeline");
         TEST_RESULT_UINT(dbPgControl(db.standby).timeline, 5, "check standby timeline");
@@ -610,7 +607,7 @@ testRun(void)
         HRN_PQ_SCRIPT_SET(
             HRN_PQ_SCRIPT_OPEN_GE_96(1, "dbname='postgres' port=5432", PG_VERSION_14, TEST_PATH "/pg1", false, NULL, NULL));
 
-        TEST_ASSIGN(db, dbGet(true, true, false), "get primary");
+        TEST_ASSIGN(db, dbGet(true, true, CFGOPTVAL_BACKUP_STANDBY_N), "get primary");
 
         // Start backup
         HRN_PQ_SCRIPT_SET(
@@ -642,7 +639,7 @@ testRun(void)
         HRN_PQ_SCRIPT_SET(
             HRN_PQ_SCRIPT_OPEN_GE_96(1, "dbname='postgres' port=5432", PG_VERSION_15, TEST_PATH "/pg1", false, NULL, NULL));
 
-        TEST_ASSIGN(db, dbGet(true, true, false), "get primary");
+        TEST_ASSIGN(db, dbGet(true, true, CFGOPTVAL_BACKUP_STANDBY_N), "get primary");
 
         // Start backup
         HRN_PQ_SCRIPT_SET(
@@ -682,7 +679,7 @@ testRun(void)
         HRN_CFG_LOAD(cfgCmdBackup, argList);
 
         // Create control file
-        HRN_PG_CONTROL_PUT(storagePgIdxWrite(0), PG_VERSION_94);
+        HRN_PG_CONTROL_PUT(storagePgIdxWrite(0), PG_VERSION_95);
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("error connecting to primary");
@@ -694,7 +691,7 @@ testRun(void)
             {.function = HRN_PQ_FINISH});
 
         TEST_ERROR(
-            dbGet(true, true, false), DbConnectError,
+            dbGet(true, true, CFGOPTVAL_BACKUP_STANDBY_N), DbConnectError,
             "unable to find primary cluster - cannot proceed\n"
             "HINT: are all available clusters in recovery?");
         TEST_RESULT_LOG(
@@ -708,13 +705,13 @@ testRun(void)
             HRN_PQ_SCRIPT_OPEN(1, "dbname='postgres' port=5432 user='bob'"),
             HRN_PQ_SCRIPT_SET_SEARCH_PATH(1),
             HRN_PQ_SCRIPT_SET_CLIENT_ENCODING(1),
-            HRN_PQ_SCRIPT_VALIDATE_QUERY(1, PG_VERSION_94, TEST_PATH "/pg", NULL, NULL),
+            HRN_PQ_SCRIPT_VALIDATE_QUERY(1, PG_VERSION_95, TEST_PATH "/pg", NULL, NULL),
             HRN_PQ_SCRIPT_SET_APPLICATION_NAME(1),
             HRN_PQ_SCRIPT_IS_STANDBY_QUERY(1, true),
             HRN_PQ_SCRIPT_CLOSE(1));
 
         TEST_ERROR(
-            dbGet(true, true, false), DbConnectError,
+            dbGet(true, true, CFGOPTVAL_BACKUP_STANDBY_N), DbConnectError,
             "unable to find primary cluster - cannot proceed\n"
             "HINT: are all available clusters in recovery?");
 
@@ -725,28 +722,29 @@ testRun(void)
             HRN_PQ_SCRIPT_OPEN(1, "dbname='postgres' port=5432 user='bob'"),
             HRN_PQ_SCRIPT_SET_SEARCH_PATH(1),
             HRN_PQ_SCRIPT_SET_CLIENT_ENCODING(1),
-            HRN_PQ_SCRIPT_VALIDATE_QUERY(1, PG_VERSION_94, TEST_PATH "/pg", NULL, NULL),
+            HRN_PQ_SCRIPT_VALIDATE_QUERY(1, PG_VERSION_95, TEST_PATH "/pg", NULL, NULL),
             HRN_PQ_SCRIPT_SET_APPLICATION_NAME(1),
             HRN_PQ_SCRIPT_IS_STANDBY_QUERY(1, false),
             HRN_PQ_SCRIPT_CLOSE(1));
 
-        TEST_ERROR(dbGet(false, false, true), DbConnectError, "unable to find standby cluster - cannot proceed");
+        TEST_ERROR(
+            dbGet(false, false, CFGOPTVAL_BACKUP_STANDBY_Y), DbConnectError, "unable to find standby cluster - cannot proceed");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("primary cluster found");
 
         HRN_PQ_SCRIPT_SET(
             HRN_PQ_SCRIPT_OPEN_GE_93(
-                1, "dbname='postgres' port=5432 user='bob'", PG_VERSION_94, TEST_PATH "/pg1", false, NULL, NULL),
+                1, "dbname='postgres' port=5432 user='bob'", PG_VERSION_95, TEST_PATH "/pg1", false, NULL, NULL),
             HRN_PQ_SCRIPT_CLOSE(1));
 
-        TEST_ASSIGN(result, dbGet(true, true, false), "get primary only");
+        TEST_ASSIGN(result, dbGet(true, true, CFGOPTVAL_BACKUP_STANDBY_N), "get primary only");
 
         TEST_RESULT_INT(result.primaryIdx, 0, "check primary id");
         TEST_RESULT_BOOL(result.primary != NULL, true, "check primary");
         TEST_RESULT_INT(result.standbyIdx, 0, "check standby id");
         TEST_RESULT_BOOL(result.standby == NULL, true, "check standby");
-        TEST_RESULT_INT(dbPgVersion(result.primary), PG_VERSION_94, "version set");
+        TEST_RESULT_INT(dbPgVersion(result.primary), PG_VERSION_95, "version set");
         TEST_RESULT_STR_Z(dbPgDataPath(result.primary), TEST_PATH "/pg1", "path set");
 
         TEST_RESULT_VOID(dbFree(result.primary), "free primary");
@@ -772,7 +770,7 @@ testRun(void)
             HRN_PQ_SCRIPT_CLOSE(1),
             HRN_PQ_SCRIPT_CLOSE(8));
 
-        TEST_ERROR(dbGet(true, true, false), DbConnectError, "more than one primary cluster found");
+        TEST_ERROR(dbGet(true, true, CFGOPTVAL_BACKUP_STANDBY_N), DbConnectError, "more than one primary cluster found");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("two standbys found but no primary");
@@ -785,7 +783,7 @@ testRun(void)
             HRN_PQ_SCRIPT_CLOSE(1));
 
         TEST_ERROR(
-            dbGet(false, true, false), DbConnectError,
+            dbGet(false, true, CFGOPTVAL_BACKUP_STANDBY_N), DbConnectError,
             "unable to find primary cluster - cannot proceed\n"
             "HINT: are all available clusters in recovery?");
 
@@ -799,7 +797,7 @@ testRun(void)
             HRN_PQ_SCRIPT_CLOSE(8),
             HRN_PQ_SCRIPT_CLOSE(1));
 
-        TEST_ASSIGN(result, dbGet(false, false, false), "get standbys");
+        TEST_ASSIGN(result, dbGet(false, false, CFGOPTVAL_BACKUP_STANDBY_N), "get standbys");
 
         TEST_RESULT_INT(result.primaryIdx, 0, "check primary id");
         TEST_RESULT_BOOL(result.primary == NULL, true, "check primary");
@@ -841,7 +839,7 @@ testRun(void)
             HRN_PQ_SCRIPT_CLOSE(8),
             HRN_PQ_SCRIPT_CLOSE(1));
 
-        TEST_ASSIGN(result, dbGet(false, true, false), "get primary and standy");
+        TEST_ASSIGN(result, dbGet(false, true, CFGOPTVAL_BACKUP_STANDBY_N), "get primary and standby");
 
         hrnLogReplaceAdd("(could not connect to server|connection to server on socket).*$", NULL, "PG ERROR", false);
         TEST_RESULT_LOG(
@@ -859,6 +857,40 @@ testRun(void)
 
         TEST_RESULT_VOID(dbFree(result.primary), "free primary");
         TEST_RESULT_VOID(dbFree(result.standby), "free standby");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("primary found and standby skipped");
+
+        argList = strLstNew();
+        hrnCfgArgRawZ(argList, cfgOptStanza, "test1");
+        hrnCfgArgKeyRawZ(argList, cfgOptRepoRetentionFull, 1, "1");
+        hrnCfgArgKeyRawZ(argList, cfgOptPgPath, 1, TEST_PATH "/pg1");
+        hrnCfgArgKeyRawZ(argList, cfgOptPgPath, 4, TEST_PATH "/pg4");
+        hrnCfgArgKeyRawZ(argList, cfgOptPgPort, 4, "5433");
+        HRN_CFG_LOAD(cfgCmdBackup, argList);
+
+        HRN_PQ_SCRIPT_SET(
+            HRN_PQ_SCRIPT_OPEN_GE_96(1, "dbname='postgres' port=5432", PG_VERSION_12, TEST_PATH "/pg1", false, NULL, NULL),
+
+            // pg4 error
+            {.session = 4, .function = HRN_PQ_CONNECTDB, .param = "[\"dbname='postgres' port=5433\"]"},
+            {.session = 4, .function = HRN_PQ_STATUS, .resultInt = CONNECTION_BAD},
+            {.session = 4, .function = HRN_PQ_ERRORMESSAGE, .resultZ = "error"},
+            {.session = 4, .function = HRN_PQ_FINISH},
+
+            HRN_PQ_SCRIPT_CLOSE(1));
+
+        TEST_ASSIGN(result, dbGet(false, true, CFGOPTVAL_BACKUP_STANDBY_PREFER), "get primary and try standby");
+
+        TEST_RESULT_LOG(
+            "P00   WARN: unable to check pg4: [DbConnectError] unable to connect to 'dbname='postgres' port=5433': error");
+
+        TEST_RESULT_INT(result.primaryIdx, 0, "check primary idx");
+        TEST_RESULT_BOOL(result.primary != NULL, true, "check primary");
+        TEST_RESULT_BOOL(result.standby == NULL, true, "check standby was not found");
+
+        TEST_RESULT_VOID(dbFree(result.primary), "free primary");
+        TEST_RESULT_VOID(dbFree(result.standby), "free standby");
     }
 
     protocolFree();
