@@ -77,6 +77,22 @@ testRun(void)
             "    default: 1024\n"
             "    allow-list: [512, 1024, 2048, 4096]\n"
             "\n"
+            "  buffer-size-range:\n"
+            "    section: global\n"
+            "    type: integer\n"
+            "    default: 1024\n"
+            "    allow-range: [512, 1024]\n"
+            "    command:\n"
+            "      backup: {}\n"
+            "\n"
+            "  cmd:\n"
+            "    section: global\n"
+            "    type: string\n"
+            "    default-type: dynamic\n"
+            "    default: bin\n"
+            "    command:\n"
+            "      backup: {}\n"
+            "\n"
             "  internal:\n"
             "    section: global\n"
             "    internal: true\n"
@@ -89,11 +105,34 @@ testRun(void)
             "    secure: true\n"
             "    default: false\n"
             "\n"
+            "  compress-type:\n"
+            "    section: global\n"
+            "    type: string-id\n"
+            "    default: gz\n"
+            "    allow-list:\n"
+            "      - none\n"
+            "      - bz2\n"
+            "      - gz\n"
+            "    command:\n"
+            "      backup: {}\n"
+            "    command-role: {}\n"
+            "\n"
             "  repo-compress-level:\n"
             "    group: repo\n"
             "    type: integer\n"
             "    default: 9\n"
-            "    allow-range: [0, 9]\n"
+            "    default:\n"
+            "      - bz2: 9\n"
+            "      - gz: 6\n"
+            "    allow-range:\n"
+            "      - bz2: [1, 9]\n"
+            "      - gz: [-1, 9]\n"
+            "    depend:\n"
+            "      option: compress-type\n"
+            "      default: 0\n"
+            "      list:\n"
+            "        - bz2\n"
+            "        - gz\n"
             "    command:\n"
             "      backup: {}\n"
             "    deprecate:\n"
@@ -151,6 +190,11 @@ testRun(void)
             "                       <example>256KiB</example>\n"
             "                   </config-key>\n"
             "\n"
+            "                   <config-key id=\"compress-type\" name=\"Compress Type\">\n"
+            "                       <summary>Compress type option command backup summary.</summary>\n"
+            "                       <text><p>Compress type option command backup description.</p></text>\n"
+            "                   </config-key>\n"
+            "\n"
             "                   <config-key id=\"internal\" name=\"Internal\">\n"
             "                       <summary>Internal option summary.</summary>\n"
             "                       <text><p>Internal option description</p></text>\n"
@@ -189,6 +233,18 @@ testRun(void)
             "               <text><p>Backup command description.</p></text>\n"
             "\n"
             "               <option-list>\n"
+            "                   <option id=\"buffer-size-range\" name=\"Buffer Size Range\">\n"
+            "                       <summary>Buffer size range option summary.</summary>\n"
+            "                       <text><p>Buffer size range option description.</p></text>\n"
+            "                       <example>512KiB</example>\n"
+            "                   </option>\n"
+            "\n"
+            "                   <option id=\"cmd\" name=\"Cmd\">\n"
+            "                       <summary>Cmd option command backup summary.</summary>\n"
+            "                       <text><p>Cmd option command backup description.</p></text>\n"
+            "                       <example>pgbackrest</example>"
+            "                   </option>\n"
+            "\n"
             "                   <option id=\"force\" name=\"Force Backup\">\n"
             "                       <summary>Force option command backup summary.</summary>\n"
             "                       <text><p>Force option command backup description.</p></text>\n"
@@ -258,6 +314,12 @@ testRun(void)
                         "example: buffer-size=128KiB\n"
                         "example: buffer-size=256KiB</code-block>"
                     "</section>"
+                    "<section id=\"option-compress-type\">"
+                        "<title>Compress Type Option (<id>--compress-type</id>)</title>"
+                        "<p>Compress type option command backup summary.</p>"
+                        "<p>Compress type option command backup description.</p>"
+                        "<code-block>default: gz</code-block>"
+                    "</section>"
                     "<section id=\"option-secure\">"
                         "<title>Secure Option (<id>--secure</id>)</title>"
                         "<p>Secure option summary.</p>"
@@ -287,6 +349,21 @@ testRun(void)
                     "<p>Backup command description.</p>"
                     "<section id=\"category-command\" toc=\"n\">"
                         "<title>Command Options</title>"
+                        "<section id=\"option-buffer-size-range\">"
+                            "<title>Buffer Size Range Option (<id>--buffer-size-range</id>)</title>"
+                            "<p>Buffer size range option summary.</p>"
+                            "<p>Buffer size range option description.</p>"
+                            "<code-block>default: 1024\n"
+                            "allowed: [512, 1024]\n"
+                            "example: --buffer-size-range=512KiB</code-block>"
+                            "</section>"
+                            "<section id=\"option-cmd\">"
+                            "<title>Cmd Option (<id>--cmd</id>)</title>"
+                            "<p>Cmd option command backup summary.</p>"
+                            "<p>Cmd option command backup description.</p>"
+                            "<code-block>default: [path of executed pgbackrest binary]\n"
+                            "example: --cmd=pgbackrest</code-block>"
+                        "</section>"
                         "<section id=\"option-force\">"
                             "<title>Force Backup Option (<id>--force</id>)</title>"
                             "<p>Force option command backup summary.</p>"
@@ -299,8 +376,14 @@ testRun(void)
                             "<title>Repo Compress Level Backup Option (<id>--repo-compress-level</id>)</title>"
                             "<p>Repo compress level option command backup summary.</p>"
                             "<p>Repo compress level option command backup description.</p>"
-                            "<code-block>default: 9\n"
-                            "allowed: 0-9\n"
+                            "<code-block>default (depending on compress-type):\n"
+                            "    bz2 - 9\n"
+                            "    gz - 6\n"
+                            "\n"
+                            "allow range (depending on compress-type):\n"
+                            "    bz2 - [1, 9]\n"
+                            "    gz - [-1, 9]\n"
+                            "\n"
                             "example: --repo1-compress-level=4</code-block>"
                         "</section>"
                     "</section>"
@@ -370,11 +453,14 @@ testRun(void)
             "\n"
             "OPTIONS\n"
             "  Backup Options:\n"
+            "    --buffer-size-range    Buffer size range option summary.\n"
+            "    --cmd                  Cmd option command backup summary.\n"
             "    --force                Force option command backup summary.\n"
             "    --repo-compress-level  Repo compress level option command backup summary.\n"
             "\n"
             "  General Options:\n"
             "    --buffer-size          Buffer size option summary.\n"
+            "    --compress-type        Compress type option command backup summary.\n"
             "    --config               config option summary.\n"
             "    --secure               Secure option summary.\n"
             "\n"
